Returns the data frame of parsing issues that vroom
encountered while reading a table downloaded with dg_pull_dataset() or
dg_refetch(). These are vroom's "parsing issues" (rows that could not be
converted to the inferred column type, e.g. a mostly-padded ISO date column
holding a few non-padded values like 2021-7-01).
Arguments
- x
A table returned by
dg_pull_dataset()ordg_refetch().
Value
A data frame with columns row, col, expected and actual
(one row per parsing issue), or NULL if there were none.